<ins>__DOLLECT__</ins>

* collecting free magazine/journal from internet

<ins>__USAGE :__</ins>


* To download 32 free issues of LINUXVOICE
> python3 -m linuxvoice.linuxvoice lv

* To select and download  1 free  issue 
> python3 linuxvoice.linuxvoice lv \<issue number\>



